# pypk

An opinionated Python packaging template generator.

## Installation

`pip install pypk`

## Getting Started

It's recommended you install and use pypk in the same virtual environment you plan to develop your Python package in.

### Usage

```sh
python -m pypk </path/to/project/root> <author-name> <author-email> --version 3.X.X
```

where `--version` is the _minimum_ Python version supported.

Run `python -m pypk --help` for more details.
